@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -558,6 +558,8 @@ void ActivityModule::syncActivities()
 
     m_globalObject->addToLog(tr("Saved %Ln activities.",
                                 "",
-                                activityDataList.length()));
+                                activityDataList.length()),
+                             true,
+                             GlobalObject::LogGood);
 }
 
