@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ class ActivityModule : public QWidget
 public:
     explicit ActivityModule(ActivityHandler *activityHandler,
                             GlobalObject *globalObject,
-                            QWidget *parent = 0);
+                            QWidget *parent = nullptr);
     ~ActivityModule();
 
     void loadActivities();
