@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ void CommandHandler::processCommand(QXmppMessage message)
     {
         // Find the matching room object
         QXmppMucRoom *room = m_globalObject->roomFromJid(bareFrom);
-        if (room)
+        if (room != nullptr)
         {
             const QString fromNick = from.join("/");
             if (fromNick == room->nickName()) // Command from ourselves!
@@ -81,9 +81,9 @@ void CommandHandler::processCommand(QXmppMessage message)
 
             // FIXME: log only if it's a recognized command?
             m_globalObject->addToLog(tr("Command from %1 in room %2: %3")
-                                     .arg(fromNick)
-                                     .arg(bareFrom)
-                                     .arg(message.body()));
+                                     .arg("'<b>" + fromNick.toHtmlEscaped() + "</b>'")
+                                     .arg("<b>" + bareFrom.toHtmlEscaped() + "</b>")
+                                     .arg(message.body().toHtmlEscaped()));
 
             commandReply = this->parseCommand(message.body(),
                                               userAccessLevel,
@@ -117,8 +117,8 @@ void CommandHandler::processCommand(QXmppMessage message)
     else // Any other type; Error type is handled before entering this method
     {
         m_globalObject->addToLog(tr("Command from %1: %2")
-                                 .arg(message.from())
-                                 .arg(message.body()));
+                                 .arg("<b>" + message.from().toHtmlEscaped() + "</b>")
+                                 .arg(message.body().toHtmlEscaped()));
 
         // TODO: handle per-user flood
 
@@ -246,10 +246,13 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
             {
                 if (userAccess < map.value("accessLevel").toInt())
                 {
-                    // FIXME: user JID should be shown here -- a previous log message shows the JID, though.
+                    // FIXME: user JID should be shown here
+                    // A previous log message shows the JID, though
                     m_globalObject->addToLog(tr("Command %1 requested without "
                                                 "the right access level.")
-                                             .arg("'" + command + "'"));
+                                             .arg("'<b>" + command + "</b>'"),
+                                             true, // In status bar, too
+                                             GlobalObject::LogBad);
 
                     qDebug() << "Command" << command
                              << "requested without privileges!";
@@ -268,10 +271,9 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
                 }
                 else if (commandType == 1)
                 {
-                    QStringList replies = map.value("randomSentence")
-                                             .toStringList();
-                    const int stringNum = qrand() % replies.count();
-                    commandReply = replies.at(stringNum);
+                    const QStringList replies = map.value("randomSentence")
+                                                   .toStringList();
+                    commandReply = Helpers::randomString(replies);
                 }
                 else if (commandType == 2)
                 {
@@ -296,9 +298,13 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
                     {
                         m_globalObject->addToLog(tr("Error loading file %1 "
                                                     "for command: %2")
-                                                 .arg(map.value("filename")
-                                                         .toString())
-                                                 .arg(command));
+                                                 .arg("<b>"
+                                                      + map.value("filename")
+                                                           .toString()
+                                                      + "</b>")
+                                                 .arg(command),
+                                                 true,
+                                                 GlobalObject::LogBad);
                         commandReply = commandFailedString;
                     }
                 }
