@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,46 +21,46 @@
 #include "commandmodule.h"
 
 
-CommandModule::CommandModule(CommandHandler *handler,
+CommandModule::CommandModule(CommandHandler *commandHandler,
                              GlobalObject *globalObject,
                              QWidget *parent) : QWidget(parent)
 {
-    this->globalObj = globalObject;
-    this->commandHandler = handler;
+    m_globalObject = globalObject;
+    m_commandHandler = commandHandler;
 
-    this->dataFile = new DataFile(globalObj->getDataDirectory()
-                                  + "/commands.axb",
-                                  this);
+    m_dataFile = new DataFile(m_globalObject->getDataDirectory()
+                              + "/commands.axb",
+                              this);
 
     // Left side
-    this->syncCommandsButton = new QPushButton(QIcon::fromTheme("document-save",
-                                                                QIcon(":/images/button-save.png")),
-                                               tr("&Sync Commands"),
-                                               this);
-    connect(syncCommandsButton, SIGNAL(clicked()),
-            this, SLOT(syncCommands()));
+    m_syncCommandsButton = new QPushButton(QIcon::fromTheme("document-save",
+                                                            QIcon(":/images/button-save.png")),
+                                           tr("&Sync Commands"),
+                                           this);
+    connect(m_syncCommandsButton, &QAbstractButton::clicked,
+            this, &CommandModule::syncCommands);
 
 
 
-    this->commandListWidget = new QListWidget(this);
-    commandListWidget->setDragDropMode(QAbstractItemView::InternalMove); // Movable items
-    connect(commandListWidget, SIGNAL(currentRowChanged(int)),
-            this, SLOT(onCommandSelected(int)));
+    m_commandListWidget = new QListWidget(this);
+    m_commandListWidget->setDragDropMode(QAbstractItemView::InternalMove); // Movable items
+    connect(m_commandListWidget, &QListWidget::currentRowChanged,
+            this, &CommandModule::onCommandSelected);
 
 
-    this->addCommandButton = new QPushButton(QIcon::fromTheme("list-add",
-                                                              QIcon(":/images/list-add.png")),
-                                             tr("&Add Command"),
-                                             this);
-    connect(addCommandButton, SIGNAL(clicked()),
-            this, SLOT(addCommand()));
+    m_addCommandButton = new QPushButton(QIcon::fromTheme("list-add",
+                                                          QIcon(":/images/list-add.png")),
+                                         tr("&Add Command"),
+                                         this);
+    connect(m_addCommandButton, &QAbstractButton::clicked,
+            this, &CommandModule::addCommand);
 
-    this->removeCommandButton = new QPushButton(QIcon::fromTheme("list-remove",
-                                                                 QIcon(":/images/list-remove.png")),
-                                                tr("&Remove Command"),
-                                                this);
-    connect(removeCommandButton, SIGNAL(clicked()),
-            this, SLOT(removeCommand()));
+    m_removeCommandButton = new QPushButton(QIcon::fromTheme("list-remove",
+                                                             QIcon(":/images/list-remove.png")),
+                                            tr("&Remove Command"),
+                                            this);
+    connect(m_removeCommandButton, &QAbstractButton::clicked,
+            this, &CommandModule::removeCommand);
 
 
 
@@ -70,7 +70,10 @@ CommandModule::CommandModule(CommandHandler *handler,
     connect(triggerLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(onTriggerChanged(QString)));
 
-    this->helpLineEdit = new QLineEdit(this);
+    m_helpLineEdit = new QLineEdit(this);
+    m_helpLineEdit->setPlaceholderText(tr("Explanation shown to users with "
+                                          "the %1 command")
+                                       .arg("!help"));
 
     this->accessLevelSpinbox = new QSpinBox(this);
     accessLevelSpinbox->setRange(0, 100);
@@ -113,12 +116,12 @@ CommandModule::CommandModule(CommandHandler *handler,
     QFont helpFont;
     helpFont.setItalic(true);
 
-    this->typeHelpLabel = new QLabel(this);
-    typeHelpLabel->setFont(helpFont);
-    typeHelpLabel->setWordWrap(true);
-    typeHelpLabel->setContentsMargins(16, 1, 16, 1);
-    typeHelpLabel->setSizePolicy(QSizePolicy::MinimumExpanding,
-                                 QSizePolicy::Minimum);
+    m_typeExplanationLabel = new QLabel(this);
+    m_typeExplanationLabel->setFont(helpFont);
+    m_typeExplanationLabel->setWordWrap(true);
+    m_typeExplanationLabel->setContentsMargins(16, 1, 16, 1);
+    m_typeExplanationLabel->setSizePolicy(QSizePolicy::MinimumExpanding,
+                                          QSizePolicy::Minimum);
 
     connect(typeCombobox, SIGNAL(currentIndexChanged(int)),
             this, SLOT(onTypeChanged(int)));
@@ -194,20 +197,20 @@ CommandModule::CommandModule(CommandHandler *handler,
 
 
 
-    this->saveCommandButton = new QPushButton(QIcon::fromTheme("document-save",
-                                                               QIcon(":/images/button-save.png")),
-                                              tr("Save &Command"),
-                                              this);
-    connect(saveCommandButton, SIGNAL(clicked()),
-            this, SLOT(saveCommand()));
+    m_saveCommandButton = new QPushButton(QIcon::fromTheme("document-save",
+                                                           QIcon(":/images/button-save.png")),
+                                          tr("Save &Command"),
+                                          this);
+    connect(m_saveCommandButton, &QAbstractButton::clicked,
+            this, &CommandModule::saveCommand);
 
 
     // Layout
-    this->leftLayout = new QVBoxLayout();
-    leftLayout->addWidget(syncCommandsButton);
-    leftLayout->addWidget(commandListWidget);
-    leftLayout->addWidget(addCommandButton);
-    leftLayout->addWidget(removeCommandButton);
+    m_leftLayout = new QVBoxLayout();
+    m_leftLayout->addWidget(m_syncCommandsButton);
+    m_leftLayout->addWidget(m_commandListWidget);
+    m_leftLayout->addWidget(m_addCommandButton);
+    m_leftLayout->addWidget(m_removeCommandButton);
 
     // These go in a sublayout to avoid spacing issues between them
     this->typeLayout = new QVBoxLayout();
@@ -223,11 +226,11 @@ CommandModule::CommandModule(CommandHandler *handler,
 
     this->formLayout = new QFormLayout();
     formLayout->addRow(tr("Command"),         triggerLineEdit);
-    formLayout->addRow(tr("Help Text"),       helpLineEdit);
+    formLayout->addRow(tr("Help Text"),       m_helpLineEdit);
     formLayout->addRow(tr("Access Level"),    accessLevelSpinbox);
 
     formLayout->addRow(tr("Type"),            typeCombobox);
-    formLayout->addWidget(typeHelpLabel);
+    formLayout->addWidget(m_typeExplanationLabel);
     formLayout->addRow(QString(), typeLayout);
 
     formLayout->addRow(tr("Reply Pattern"),   outputLineEdit);
@@ -238,22 +241,22 @@ CommandModule::CommandModule(CommandHandler *handler,
     this->rightLayout = new QVBoxLayout();
     rightLayout->addLayout(formLayout);
     rightLayout->addStretch();
-    rightLayout->addWidget(saveCommandButton, 0, Qt::AlignRight);
+    rightLayout->addWidget(m_saveCommandButton, 0, Qt::AlignRight);
 
-    this->rightWidget = new QWidget(this);
-    rightWidget->setLayout(rightLayout);
+    m_rightWidget = new QWidget(this);
+    m_rightWidget->setLayout(rightLayout);
 
 
-    this->mainLayout = new QHBoxLayout();
-    mainLayout->setContentsMargins(0, 0, 0, 0);
-    mainLayout->addLayout(leftLayout,  1);
-    mainLayout->addWidget(rightWidget, 5);
-    this->setLayout(mainLayout);
+    m_mainLayout = new QHBoxLayout();
+    m_mainLayout->setContentsMargins(0, 0, 0, 0);
+    m_mainLayout->addLayout(m_leftLayout,  1);
+    m_mainLayout->addWidget(m_rightWidget, 5);
+    this->setLayout(m_mainLayout);
 
 
     this->onTypeChanged(0); // Select first type to show its extra widget
-    this->removeCommandButton->setDisabled(true);
-    this->rightWidget->setDisabled(true);
+    m_removeCommandButton->setDisabled(true);
+    m_rightWidget->setDisabled(true);
 
     this->loadCommands();
 
@@ -276,7 +279,7 @@ CommandModule::~CommandModule()
  */
 void CommandModule::loadCommands()
 {
-    QVariantList commandDataList = this->dataFile->loadData();
+    const QVariantList commandDataList = m_dataFile->loadData();
 
     foreach (QVariant listItem, commandDataList)
     {
@@ -325,14 +328,14 @@ void CommandModule::loadCommands()
         item->setData(Qt::UserRole + 5, map.value("outputPattern"));
         item->setData(Qt::UserRole + 6, map.value("privateReply"));
 
-        this->commandListWidget->addItem(item);
+        m_commandListWidget->addItem(item);
     }
 
-    this->commandHandler->setCommandData(commandDataList);
+    m_commandHandler->setCommandData(commandDataList);
 
-    this->globalObj->addToLog(tr("Loaded %Ln command(s).",
-                                 "",
-                                 commandDataList.length()));
+    m_globalObject->addToLog(tr("Loaded %Ln command(s).",
+                                "",
+                                commandDataList.length()));
 }
 
 
@@ -403,8 +406,10 @@ bool CommandModule::validateCommand(int commandType)
     if (!errorMessage.isEmpty())
     {
         QMessageBox::warning(this,
-                             tr("Error validating fields"),
-                             errorMessage);
+                             tr("Error validating fields") +  " - AkariXB",
+                             "\n"
+                             + errorMessage
+                             + "\t\t\t\t\t\n"); // Ensure some width
         return false;
     }
 
@@ -422,7 +427,7 @@ bool CommandModule::validateCommand(int commandType)
 
 void CommandModule::onTriggerChanged(QString newTrigger)
 {
-    this->saveCommandButton->setDisabled(newTrigger.trimmed().isEmpty());
+    m_saveCommandButton->setDisabled(newTrigger.trimmed().isEmpty());
 }
 
 
@@ -452,31 +457,31 @@ void CommandModule::addCommand()
     QListWidgetItem *item = new QListWidgetItem("-- "
                                                 + tr("New Command")
                                                 + " --");
-    this->commandListWidget->addItem(item);
+    m_commandListWidget->addItem(item);
 
-    int lastRow = commandListWidget->count() - 1;
-    commandListWidget->setCurrentRow(lastRow);
-    commandListWidget->setCurrentItem(item);
+    const int lastRow = m_commandListWidget->count() - 1;
+    m_commandListWidget->setCurrentRow(lastRow);
+    m_commandListWidget->setCurrentItem(item);
     item->setSelected(true);
 
-    this->saveCommandButton->setDisabled(true); // Until something's entered
+    m_saveCommandButton->setDisabled(true); // Until something's entered
     this->triggerLineEdit->setFocus();
 }
 
 
 void CommandModule::removeCommand()
 {
-    int row = this->commandListWidget->currentRow();
+    const int row = m_commandListWidget->currentRow();
     if (row != -1)
     {
-        QListWidgetItem *item = this->commandListWidget->takeItem(row);
+        QListWidgetItem *item = m_commandListWidget->takeItem(row);
         delete item;
     }
 
-    if (commandListWidget->count() == 0) // No commands left
+    if (m_commandListWidget->count() == 0) // No commands left
     {
-        this->removeCommandButton->setDisabled(true);
-        this->rightWidget->setDisabled(true);
+        m_removeCommandButton->setDisabled(true);
+        m_rightWidget->setDisabled(true);
     }
 }
 
@@ -488,10 +493,10 @@ void CommandModule::onCommandSelected(int row)
         return;
     }
 
-    QListWidgetItem *item = commandListWidget->item(row);
+    QListWidgetItem *item = m_commandListWidget->item(row);
 
     this->triggerLineEdit->setText(item->data(Qt::UserRole).toString());
-    this->helpLineEdit->setText(item->data(Qt::UserRole + 1).toString());
+    m_helpLineEdit->setText(item->data(Qt::UserRole + 1).toString());
     this->accessLevelSpinbox->setValue(item->data(Qt::UserRole + 2).toInt());
     this->typeCombobox->setCurrentIndex(item->data(Qt::UserRole + 3).toInt());
 
@@ -543,15 +548,15 @@ void CommandModule::onCommandSelected(int row)
     this->privateReplyCheckbox->setChecked(item->data(Qt::UserRole + 6).toBool());
 
 
-    this->removeCommandButton->setEnabled(true);
-    this->rightWidget->setEnabled(true);
+    m_removeCommandButton->setEnabled(true);
+    m_rightWidget->setEnabled(true);
 }
 
 
 void CommandModule::onTypeChanged(int commandType)
 {
     // Show the informational text for this command type
-    this->typeHelpLabel->setText(typeCombobox->itemData(commandType).toString());
+    m_typeExplanationLabel->setText(typeCombobox->itemData(commandType).toString());
 
     this->staticLineEdit->hide();
     this->randomListWidget->hide();
@@ -598,12 +603,12 @@ void CommandModule::saveCommand()
     int commandType = typeCombobox->currentIndex();
 
     // Check for duplicates
-    for (int counter = 0; counter < commandListWidget->count(); ++counter)
+    for (int counter = 0; counter < m_commandListWidget->count(); ++counter)
     {
-        QListWidgetItem *commandItem = commandListWidget->item(counter);
+        QListWidgetItem *commandItem = m_commandListWidget->item(counter);
         if (commandItem->data(Qt::UserRole).toString() == newTrigger)
         {
-            if (commandItem != this->commandListWidget->currentItem())
+            if (commandItem != m_commandListWidget->currentItem())
             {
                 QMessageBox::warning(this,
                                      tr("Command exists"),
@@ -623,12 +628,12 @@ void CommandModule::saveCommand()
         return;
     }
 
-    QListWidgetItem *item = this->commandListWidget->currentItem();
+    QListWidgetItem *item = m_commandListWidget->currentItem();
 
     triggerLineEdit->setText(newTrigger); // Show it as it will be stored
     item->setText(newTrigger);
     item->setData(Qt::UserRole,     newTrigger);
-    item->setData(Qt::UserRole + 1, helpLineEdit->text().trimmed());
+    item->setData(Qt::UserRole + 1, m_helpLineEdit->text().trimmed());
     item->setData(Qt::UserRole + 2, accessLevelSpinbox->value());
     item->setData(Qt::UserRole + 3, commandType);
 
@@ -671,7 +676,7 @@ void CommandModule::saveCommand()
     item->setData(Qt::UserRole + 6, this->privateReplyCheckbox->isChecked());
 
 
-    this->commandListWidget->setFocus();
+    m_commandListWidget->setFocus();
 }
 
 
@@ -684,9 +689,9 @@ void CommandModule::syncCommands()
 {
     QVariantList commandDataList;
 
-    for (int counter = 0; counter < commandListWidget->count(); ++counter)
+    for (int counter = 0; counter < m_commandListWidget->count(); ++counter)
     {
-        QListWidgetItem *item = commandListWidget->item(counter);
+        QListWidgetItem *item = m_commandListWidget->item(counter);
         const int commandType = item->data(Qt::UserRole + 3).toInt();
         const QString commandTrigger = item->data(Qt::UserRole).toString()
                                                                .trimmed();
@@ -733,11 +738,13 @@ void CommandModule::syncCommands()
     }
 
 
-    this->commandHandler->setCommandData(commandDataList);
-    this->dataFile->saveData(commandDataList);
+    m_commandHandler->setCommandData(commandDataList);
+    m_dataFile->saveData(commandDataList);
 
-    this->globalObj->addToLog(tr("Saved %Ln command(s).",
-                                 "",
-                                 commandDataList.length()));
+    m_globalObject->addToLog(tr("Saved %Ln command(s).",
+                                "",
+                                commandDataList.length()),
+                             true,
+                             GlobalObject::LogGood);
 }
 
