@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -49,7 +49,8 @@ class CommandModule : public QWidget
     Q_OBJECT
 
 public:
-    explicit CommandModule(CommandHandler *handler, GlobalObject *globalObject,
+    explicit CommandModule(CommandHandler *commandHandler,
+                           GlobalObject *globalObject,
                            QWidget *parent = nullptr);
     ~CommandModule();
 
@@ -80,23 +81,23 @@ public slots:
 
 
 private:
-    QHBoxLayout *mainLayout;
+    QHBoxLayout *m_mainLayout;
 
-    QVBoxLayout *leftLayout;
-    QPushButton *syncCommandsButton;
-    QListWidget *commandListWidget;
-    QPushButton *addCommandButton;
-    QPushButton *removeCommandButton;
+    QVBoxLayout *m_leftLayout;
+    QPushButton *m_syncCommandsButton;
+    QListWidget *m_commandListWidget;
+    QPushButton *m_addCommandButton;
+    QPushButton *m_removeCommandButton;
 
 
-    QWidget *rightWidget;
+    QWidget *m_rightWidget;
     QVBoxLayout *rightLayout;
     QFormLayout *formLayout;
     QLineEdit *triggerLineEdit;
-    QLineEdit *helpLineEdit;
+    QLineEdit *m_helpLineEdit;
     QSpinBox  *accessLevelSpinbox;
     QComboBox *typeCombobox;
-    QLabel *typeHelpLabel;
+    QLabel *m_typeExplanationLabel;
 
 
     QVBoxLayout *typeLayout;
@@ -105,6 +106,7 @@ private:
 
     QHBoxLayout *filenameLayout;
     QLabel *filenameLabel;
+    QString textFilename;
     QPushButton *filenameButton;
 
     StringListWidget *keywordListWidget;
@@ -121,13 +123,12 @@ private:
     QCheckBox *privateReplyCheckbox;
 
 
-    QPushButton *saveCommandButton;
+    QPushButton *m_saveCommandButton;
 
-    QString textFilename;
 
-    DataFile *dataFile;
-    CommandHandler *commandHandler;
-    GlobalObject *globalObj;
+    DataFile *m_dataFile;
+    CommandHandler *m_commandHandler;
+    GlobalObject *m_globalObject;
 };
 
 #endif // COMMANDMODULE_H
