@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
     // Tab 1: General options
     m_adminJidListWidget = new StringListWidget(false, this);
+    m_adminJidListWidget->setDuplicatesAllowed(false);
     m_adminJidListWidget->addStringsToList(m_globalObject->getAdminJids());
 
     m_commandPrefixLineEdit = new QLineEdit(m_globalObject->getCommandPrefix(),
@@ -220,5 +221,8 @@ void ConfigDialog::saveSettings()
 
     settings.endGroup();
     settings.sync();
+    m_globalObject->addToLog(tr("Program configuration saved."),
+                             true,
+                             GlobalObject::LogGood);
     this->hide();
 }
