@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ class DataFile : public QObject
 {
     Q_OBJECT
 public:
-    explicit DataFile(QString filename, QObject *parent = 0);
+    explicit DataFile(QString filename, QObject *parent = nullptr);
     ~DataFile();
 
     QVariantList loadData();
