@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -41,11 +41,12 @@ class GeneralModule : public QWidget
     Q_OBJECT
 
 public:
-    explicit GeneralModule(GlobalObject *globalObject, QWidget *parent = 0);
+    explicit GeneralModule(GlobalObject *globalObject,
+                           QWidget *parent = nullptr);
     ~GeneralModule();
 
     void setInfoMessage(QString message);
-    void setConnecting();
+    void setConnecting(bool state);
     void addPresence(QXmppPresence presence);
 
 
@@ -62,21 +63,21 @@ public slots:
 
 
 private:
-    QVBoxLayout *mainLayout;
-    QFormLayout *formLayout;
+    QVBoxLayout *m_mainLayout;
+    QFormLayout *m_formLayout;
 
-    QLabel *infoLabel;
+    QLabel *m_infoLabel;
 
-    QLabel *activityLabel;
-    QLabel *statusMessageLabel;
+    QLabel *m_activityLabel;
+    QLabel *m_statusMessageLabel;
 
-    QTextBrowser *tmpPresenceBrowser;
+    QTextBrowser *m_tmpPresenceBrowser;
 
-    QPushButton *connectButton;
-    QPushButton *disconnectButton;
+    QPushButton *m_connectButton;
+    QPushButton *m_disconnectButton;
 
-    QXmppClient *xmppClient;
-    GlobalObject *globalObj;
+    QXmppClient *m_xmppClient;
+    GlobalObject *m_globalObject;
 };
 
 #endif // GENERALMODULE_H
