@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -171,9 +171,10 @@ QString GlobalObject::getDataDirectory()
 
 
 
-void GlobalObject::addToLog(QString message, bool inStatusBar)
+void GlobalObject::addToLog(QString message, bool inStatusBar,
+                            int messageType)
 {
-    emit logMessage(message);
+    emit logMessage(message, messageType);
 
     if (inStatusBar)
     {
@@ -233,6 +234,55 @@ QStringList GlobalObject::getJoinedRooms()
 }
 
 
+void GlobalObject::addFullyJoinedRoom(QString roomJid)
+{
+    if (!m_fullyJoinedRooms.contains(roomJid))
+    {
+        m_fullyJoinedRooms.append(roomJid);
+    }
+
+    qDebug() << "addFullyJoinedRoom()" << roomJid;
+    qDebug() << "Current list:" << m_fullyJoinedRooms;
+}
+
+void GlobalObject::removeFullyJoinedRoom(QString roomJid)
+{
+    m_fullyJoinedRooms.removeAll(roomJid);
+
+    qDebug() << "removeFullyJoinedRoom()" << roomJid;
+    qDebug() << "Current list:" << m_fullyJoinedRooms;
+}
+
+QStringList GlobalObject::getFullyJoinedRooms()
+{
+    return m_fullyJoinedRooms;
+}
+
+bool GlobalObject::isRoomFullyJoined(QString roomJid)
+{
+    return m_fullyJoinedRooms.contains(roomJid);
+}
+
+/*
+ * Keep a list of configured rooms, joined or not, for checks
+ *
+ */
+void GlobalObject::setConfiguredRoomsList(QStringList roomList)
+{
+    m_configuredRooms = roomList;
+}
+
+QStringList GlobalObject::getConfiguredRoomsList()
+{
+    return m_configuredRooms;
+}
+
+bool GlobalObject::isRoomConfigured(QString roomJid)
+{
+    return m_configuredRooms.contains(roomJid);
+}
+
+
 QXmppMucRoom *GlobalObject::roomFromJid(QString roomJid)
 {
     foreach (QXmppMucRoom *room, m_xmppMucManager->rooms())
@@ -243,7 +293,7 @@ QXmppMucRoom *GlobalObject::roomFromJid(QString roomJid)
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 
@@ -283,17 +333,18 @@ void GlobalObject::sendMessageToJid(QString jid, QString message)
 {
     if (!jid.isEmpty() && !message.isEmpty())
     {
-        if (this->getJoinedRooms().contains(jid))
+        if (m_joinedRooms.contains(jid))
         {
             QXmppMucRoom *room = this->roomFromJid(jid);
-            if (room)
+            if (room != nullptr)
             {
                 room->sendMessage(message);
             }
         }
         else
         {
-            m_xmppClient->sendMessage(jid, message);
+            // Send it using this function so it gets logged
+            this->sendPrivateMessage(jid, message);
         }
     }
 }
@@ -304,6 +355,16 @@ void GlobalObject::sendPrivateMessage(QString jid, QString message)
 {
     m_xmppClient->sendMessage(jid, message);
 
+    // Let others know, to log it and so on
     emit privateMessageSent(jid, message);
 }
 
+/*
+ * Request empty tab to be added in ChatModule, and the module to be focused
+ *
+ */
+void GlobalObject::startPrivateConversation(QString jid)
+{
+    emit conversationTabRequested(jid);
+}
+
