@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -81,7 +81,9 @@ public:
     //////////
 
 
-    void addToLog(QString message, bool inStatusBar=true);
+    void addToLog(QString message,
+                  bool inStatusBar=true,
+                  int messageType=LogNormal);
     void showNotification(QString title, QString message);
 
     void setConnected(bool state);
@@ -91,6 +93,15 @@ public:
     void addJoinedRoom(QString roomJid);
     void removeJoinedRoom(QString roomJid);
     QStringList getJoinedRooms();
+    void addFullyJoinedRoom(QString roomJid);
+    void removeFullyJoinedRoom(QString roomJid);
+    QStringList getFullyJoinedRooms();
+    bool isRoomFullyJoined(QString roomJid);
+
+    void setConfiguredRoomsList(QStringList roomList);
+    QStringList getConfiguredRoomsList();
+    bool isRoomConfigured(QString roomJid);
+
 
     QXmppMucRoom *roomFromJid(QString roomJid);
 
@@ -104,11 +115,18 @@ public:
 
     void sendMessageToJid(QString jid, QString message);
     void sendPrivateMessage(QString jid, QString message);
+    void startPrivateConversation(QString jid);
 
+    enum logMessageType
+    {
+        LogNormal,
+        LogGood,
+        LogBad
+    };
 
 
 signals:
-    void logMessage(QString message);
+    void logMessage(QString message, int messageType);
     void showInStatusBar(QString message);
     void showNotificationPopup(QString title, QString message);
 
@@ -116,6 +134,7 @@ signals:
     void statusChanged(QXmppPresence presence);
 
     void privateMessageSent(QString jid, QString message);
+    void conversationTabRequested(QString jid);
 
 
 public slots:
@@ -134,6 +153,8 @@ private:
     QDateTime m_connectionStartTime;
 
     QStringList m_joinedRooms;
+    QStringList m_fullyJoinedRooms;
+    QStringList m_configuredRooms;
 
     QString m_ownNickname;
 
