@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@ bool Helpers::isValidJid(QString jid)
     // Matching something@something, and only one @ sign
     if (QRegExp("\\S+@\\S+").exactMatch(jid) && jid.count("@") == 1)
     {
+        // FIXME: port to QRegularExpression
         return true;
     }
 
@@ -56,9 +57,24 @@ QString Helpers::nickFromRoomJid(QString jid)
 
 QString Helpers::safeForHtml(QString text)
 {
-    text.replace("<",  "&lt;");
-    text.replace(">",  "&gt;");
-    text.replace("\n", "<br>");
+    text = text.toHtmlEscaped();
+    text.replace(QStringLiteral("\n"), QStringLiteral("<br />"));
+
+    return text;
+}
+
+/*
+ * Return the string with both kinds of newlines removed:
+ * \n, and variations of <br />
+ *
+ */
+QString Helpers::newlinesRemoved(QString text)
+{
+    text.replace(QStringLiteral("\n"),
+                 QStringLiteral(" "));
+
+    text.replace(QRegularExpression("<br.*?>"), // Non-greedy!
+                 QStringLiteral(" "));
 
     return text;
 }
@@ -73,8 +89,8 @@ QString Helpers::randomString(QStringList stringList)
 
     if (!stringList.isEmpty())
     {
-        int choice = qrand() % stringList.length();
-        if (choice < stringList.length()) // For safety
+        const int choice = qrand() % stringList.length();
+        if (choice >= 0 && choice < stringList.length()) // For safety
         {
             chosenString = stringList.at(choice);
         }
