@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 IdentityModule::IdentityModule(GlobalObject *globalObject,
                                QWidget *parent) : QWidget(parent)
 {
-    this->m_globalObject = globalObject;
+    m_globalObject = globalObject;
 
     m_dataFile = new DataFile(m_globalObject->getDataDirectory()
                               + "/identity.axb",
@@ -42,7 +42,7 @@ IdentityModule::IdentityModule(GlobalObject *globalObject,
                                      tr("&Update"),
                                      this);
     connect(m_updateButton, &QAbstractButton::clicked,
-            this, &IdentityModule::updateData);
+            this, &IdentityModule::saveIdentity);
 
 
     m_formLayout = new QFormLayout();
@@ -51,8 +51,7 @@ IdentityModule::IdentityModule(GlobalObject *globalObject,
     m_mainLayout = new QVBoxLayout();
     m_mainLayout->addLayout(m_formLayout);
     m_mainLayout->addStretch(1);
-    m_mainLayout->addWidget(new QLabel("Formal name,\n"
-                                       "likes and dislikes, etc.", this),
+    m_mainLayout->addWidget(new QLabel("Formal name, birthday, likes and dislikes, etc.", this),
                             0, Qt::AlignCenter); // TMP-------------------------------
     m_mainLayout->addStretch(2);
     m_mainLayout->addWidget(m_updateButton, 0, Qt::AlignRight);
@@ -83,19 +82,26 @@ void IdentityModule::loadIdentity()
     QString nickname = identityMap.value("nickname").toString();
     if (nickname.isEmpty())
     {
-        nickname = "AkariXB"; // Default
+        nickname = QStringLiteral("Akari"); // Default
     }
     m_nickLineEdit->setText(nickname);
     m_globalObject->setOwnNickname(nickname);
 
 
-    // Load other values, likes list, dislikes list, etc
+    // Load other values, likes list, dislikes list, date of birth, etc
 
 
     if (!identityDataList.isEmpty())
     {
         m_globalObject->addToLog(tr("Loaded identity data for %1.",
-                                    "%1 is a nickname").arg(nickname));
+                                    "%1 is a nickname")
+                                 .arg("<b>" + nickname + "</b>"));
+    }
+    else
+    {
+        m_globalObject->addToLog(tr("Identity data has not been defined yet."),
+                                 true,
+                                 GlobalObject::LogBad);
     }
 }
 
@@ -105,12 +111,12 @@ void IdentityModule::loadIdentity()
 //////////////////////////////////////////////////////////////////////////////
 
 
-void IdentityModule::updateData()
+void IdentityModule::saveIdentity()
 {
     QString nickname = m_nickLineEdit->text().trimmed();
     if (nickname.isEmpty())
     {
-        nickname = "AkariXB";  // Default
+        nickname = QStringLiteral("Akari");  // Default
         m_nickLineEdit->setText(nickname);
     }
 
@@ -127,6 +133,9 @@ void IdentityModule::updateData()
     m_dataFile->saveData(identityDataList);
 
     m_globalObject->addToLog(tr("Saved identity data for %1.",
-                                "%1 is a nickname").arg(nickname));
+                                "%1 is a nickname")
+                             .arg("<b>" + nickname + "</b>"),
+                             true,
+                             GlobalObject::LogGood);
 }
 
