@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -40,7 +40,8 @@ class IdentityModule : public QWidget
     Q_OBJECT
 
 public:
-    explicit IdentityModule(GlobalObject *globalObject, QWidget *parent = 0);
+    explicit IdentityModule(GlobalObject *globalObject,
+                            QWidget *parent = nullptr);
     ~IdentityModule();
 
     void loadIdentity();
@@ -50,7 +51,7 @@ signals:
 
 
 public slots:
-    void updateData();
+    void saveIdentity();
 
 
 private:
