@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -56,11 +56,12 @@
 #include "globalobject.h"
 #include "connectiondialog.h"
 #include "configdialog.h"
-
+#include "helpwidget.h"
 
 #include "generalmodule.h"
 #include "roommodule.h"
 #include "chatmodule.h"
+#include "contactsmodule.h"
 #include "commandmodule.h"
 #include "conversationmodule.h"
 #include "activitymodule.h"
@@ -71,6 +72,7 @@
 #include "commandhandler.h"
 #include "activityhandler.h"
 #include "variableparser.h"
+#include "helpers.h"
 
 
 class MainWindow : public QMainWindow
@@ -103,6 +105,7 @@ public slots:
     void autoConnectToServer();
     void onConnected();
     void disconnectFromServer();
+    void abortConnectionAttempts();
     void onDisconnected();
     void onConnectionTimerAbort();
     void onStatusChanged(QXmppPresence presence);
@@ -114,6 +117,7 @@ public slots:
     void onNetworkError(QXmppClient::Error error);
 
     void setChatsTitle(int count);
+    void focusChatsModule();
 
     void visitWebsite();
     void visitBugTracker();
@@ -137,53 +141,63 @@ private:
     GlobalObject *m_globalObject;
 
     // Menus
-    QMenu *sessionMenu;
-    QAction *sessionConnectAction;
-    QAction *sessionDisconnectAction;
-    QAction *sessionQuitAction;
+    QMenu *m_sessionMenu;
+    QAction *m_sessionConnectAction;
+    QAction *m_sessionDisconnectAction;
+    QAction *m_sessionAbortAction;
+    QAction *m_sessionQuitAction;
 
-    QMenu *settingsMenu;
-    QAction *settingsConfigAction;
+    QMenu *m_settingsMenu;
+    QAction *m_settingsConfigAction;
 
-    QMenu *helpMenu;
-    QAction *helpWebsiteAction;
-    QAction *helpBugTrackerAction;
-    QAction *helpAboutXmppAction;
-    QAction *helpAboutAction;
+    QMenu *m_helpMenu;
+    QAction *m_helpGeneralHelpAction;
+    QAction *m_helpWebsiteAction;
+    QAction *m_helpBugTrackerAction;
+    QAction *m_helpAboutXmppAction;
+    QAction *m_helpAboutAction;
 
 
-    QSystemTrayIcon *systrayIcon;
-    QMenu *systrayMenu;
-    QAction *trayTitleSeparatorAction;
-    QAction *trayShowWindowAction;
+    QSystemTrayIcon *m_systrayIcon;
+    bool m_trayIconAvailable;
+    QMenu *m_systrayMenu;
+    QAction *m_trayTitleAction;
+    QAction *m_trayShowWindowAction;
 
 
     // GUI
-    QWidget *mainWidget;
-    QHBoxLayout *mainLayout;
-    QListWidget *categoriesList;
-    QStackedWidget *stackedWidget;
+    QWidget *m_mainWidget;
+    QHBoxLayout *m_mainLayout;
+    QListWidget *m_categoriesList;
+    QStackedWidget *m_stackedWidget;
 
-    QLabel *statusBarLabel;
+    QLabel *m_statusBarMessageLabel;
+    QLabel *m_statusBarIconLabel; // Will hold an icon indicating away, DND...
 
 
-    ConnectionDialog *connectionDialog;
-    ConfigDialog *configDialog;
+    // Dialogs
+    ConnectionDialog *m_connectionDialog;
+    ConfigDialog     *m_configDialog;
+    HelpWidget       *m_helpWidget;
 
-    GeneralModule *generalModule;
-    RoomModule *roomModule;
-    ChatModule *chatModule;
-    CommandModule *commandModule;
-    ConversationModule *conversationModule;
-    ActivityModule *activityModule;
-    IdentityModule *identityModule;
-    LogModule *logModule;
+    // Embedded modules
+    GeneralModule      *m_generalModule;
+    RoomModule         *m_roomModule;
+    ChatModule         *m_chatModule;
+    ContactsModule     *m_contactsModule;
+    CommandModule      *m_commandModule;
+    ConversationModule *m_conversationModule;
+    ActivityModule     *m_activityModule;
+    IdentityModule     *m_identityModule;
+    LogModule          *m_logModule;
 
-    MessageHandler *messageHandler;
-    CommandHandler *commandHandler;
-    ActivityHandler *activityHandler;
 
-    VariableParser *variableParser;
+    VariableParser *m_variableParser;
+
+    MessageHandler  *m_messageHandler;
+    CommandHandler  *m_commandHandler;
+    ActivityHandler *m_activityHandler;
+
 
     QTimer *m_initialConnectionTimer;
 
