@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -45,14 +45,14 @@ MessageHandler::~MessageHandler()
 void MessageHandler::processMessage(QXmppMessage message)
 {
     QStringList from = message.from().split("/");
-    QString bareFrom = from.first();
+    const QString bareFrom = from.first();
     from.removeFirst();
 
     if (message.type() == QXmppMessage::GroupChat)
     {
         // Find the matching room object
         QXmppMucRoom *room = m_globalObject->roomFromJid(bareFrom);
-        if (room)
+        if (room != nullptr)
         {
             const QString fromNick = from.join("/");
 
@@ -84,12 +84,16 @@ void MessageHandler::processMessage(QXmppMessage message)
     }
     else if (message.type() == QXmppMessage::Headline)
     {
-        const QString headlineMessage = tr("Headline from %1").arg(message.from())
-                                        + ": " + message.subject() + "\n"
-                                        + message.body();
-
+        const QString headlineMessage = tr("Headline from %1: %2",
+                                           "%1 is a user's address,"
+                                           "%2 is the title of a message")
+                                        .arg("'<b>" + message.from().toHtmlEscaped()
+                                             + "</b>'")
+                                        .arg(message.subject().toHtmlEscaped())
+                                        + "<br />"
+                                        + message.body().toHtmlEscaped();
+        // FIXME: log as important?
         m_globalObject->addToLog(headlineMessage);
-
         qDebug() << "Message type is Headline:";
         qDebug() << "Subject:" << message.subject();
         qDebug() << "Body:" << message.body();
@@ -97,11 +101,15 @@ void MessageHandler::processMessage(QXmppMessage message)
     else // QXmppMessage::Error
     {
         const QString errorMessage = tr("Error %1 from %2: %3")
-                                     .arg(message.error().code())
-                                     .arg(message.from())
+                                     .arg(QString("<b>%1</b>")
+                                          .arg(message.error().code()))
+                                     .arg("'<b>" + message.from().toHtmlEscaped()
+                                          + "</b>'")
                                      .arg(message.error().text());
 
-        m_globalObject->addToLog(errorMessage);
+        m_globalObject->addToLog(errorMessage,
+                                 true, // Show in status bar too
+                                 GlobalObject::LogBad);
 
         qDebug() << "Message type is Error:";
         qDebug() << "Subject:" << message.subject();
