@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -26,6 +26,8 @@ StringListWidget::StringListWidget(bool forKeyValues,
 {
     m_forKeyValues = forKeyValues;
     m_lowercaseItems = false;
+    // By default, don't allow duplicates when it's a key-value kind of widget
+    m_duplicatesAllowed = !m_forKeyValues;
 
 
     m_listWidget = new QListWidget(this);
@@ -36,6 +38,8 @@ StringListWidget::StringListWidget(bool forKeyValues,
     m_addButton = new QToolButton(this);
     m_addButton->setIcon(QIcon::fromTheme("list-add",
                                           QIcon(":/images/list-add.png")));
+    m_addButton->setToolTip("<b></b>" // HTMLize to get wordwrap
+                            + tr("Add an item to the list"));
     connect(m_addButton, &QAbstractButton::clicked,
             this, &StringListWidget::addToList);
 
@@ -43,6 +47,9 @@ StringListWidget::StringListWidget(bool forKeyValues,
     m_editButton = new QToolButton(this);
     m_editButton->setIcon(QIcon::fromTheme("document-edit",
                                            QIcon(":/images/button-edit.png")));
+    m_editButton->setToolTip("<b></b>"
+                             + tr("Edit the selected item (you can also "
+                                  "double-click it)"));
     connect(m_editButton, &QAbstractButton::clicked,
             this, &StringListWidget::editItem);
 
@@ -50,6 +57,8 @@ StringListWidget::StringListWidget(bool forKeyValues,
     m_removeButton = new QToolButton(this);
     m_removeButton->setIcon(QIcon::fromTheme("list-remove",
                                              QIcon(":/images/list-remove.png")));
+    m_removeButton->setToolTip("<b></b>"
+                               + tr("Remove the selected item"));
     connect(m_removeButton, &QAbstractButton::clicked,
             this, &StringListWidget::removeFromList);
 
@@ -64,6 +73,8 @@ StringListWidget::StringListWidget(bool forKeyValues,
                                                           QIcon(":/images/button-apply.png")),
                                          QString(),
                                          this);
+        m_updateButton->setToolTip("<b></b>"
+                                   + tr("Update the definition of the item"));
         connect(m_updateButton, &QAbstractButton::clicked,
                 this, &StringListWidget::updateItemText);
     }
@@ -101,9 +112,14 @@ StringListWidget::~StringListWidget()
 }
 
 
-void StringListWidget::setLowercaseItems(bool lowercase)
+void StringListWidget::setLowercaseItems(bool lowercaseItems)
 {
-    m_lowercaseItems = lowercase;
+    m_lowercaseItems = lowercaseItems;
+}
+
+void StringListWidget::setDuplicatesAllowed(bool duplicatesAllowed)
+{
+    m_duplicatesAllowed = duplicatesAllowed;
 }
 
 
@@ -127,7 +143,14 @@ void StringListWidget::clearList()
 
 void StringListWidget::addStringsToList(QStringList stringList)
 {
-    m_listWidget->addItems(stringList);
+    m_listWidget->addItems(stringList); // FIXME? Check duplicates if needed
+
+    // If nothing's selected, select the first one, so all buttons make sense
+    if (m_listWidget->currentRow() < 0)
+    {
+        m_listWidget->setCurrentRow(0);
+    }
+
     enableRelevantButtons();
 }
 
@@ -156,6 +179,8 @@ void StringListWidget::addItemsToList(QVariantMap stringMap)
             key = key.toLower();
         }
 
+        // FIXME? Check for duplicates? Data comes from a file, should be OK
+
         QListWidgetItem *item = new QListWidgetItem(key);
         item->setData(Qt::UserRole, stringMap.value(key));
 
@@ -174,13 +199,28 @@ QVariantMap StringListWidget::getItemsFromList()
     for (int counter = 0; counter < m_listWidget->count(); ++counter)
     {
         stringMap.insert(m_listWidget->item(counter)->text(),
-                         m_listWidget->item(counter)->data(Qt::UserRole).toString());
+                         m_listWidget->item(counter)->data(Qt::UserRole)
+                                                    .toString());
     }
 
     return stringMap;
 }
 
 
+bool StringListWidget::stringExists(QString text)
+{
+    for (int counter = 0; counter < m_listWidget->count(); ++counter)
+    {
+        if (m_listWidget->item(counter)->text() == text)
+        {
+            return true;
+        }
+    }
+
+    return false;
+}
+
+
 void StringListWidget::enableRelevantButtons()
 {
     const bool buttonEnabled = (m_listWidget->count() > 0);
@@ -204,7 +244,7 @@ void StringListWidget::enableRelevantButtons()
 void StringListWidget::addToList()
 {
     QString newString = QInputDialog::getText(this,
-                                              tr("Enter text"),
+                                              tr("Enter text") + " - AkariXB",
                                               tr("Enter a new line of text "
                                                  "for the list") // kinda TMP
                                               + "\n"
@@ -219,6 +259,17 @@ void StringListWidget::addToList()
             newString = newString.toLower();
         }
 
+        if (!m_duplicatesAllowed && this->stringExists(newString))
+        {
+            QMessageBox::warning(this,
+                                 tr("The item already exists") + " - AkariXB",
+                                 tr("Error: There is already an item in "
+                                    "the list with the text %1, and this "
+                                    "list does not allow duplicates.")
+                                 .arg("<b>'" + newString + "'</b>"));
+            return;
+        }
+
         m_listWidget->addItem(newString);
 
         const int lastRow = m_listWidget->count() - 1;
@@ -245,7 +296,7 @@ void StringListWidget::editItem()
         // FIXME: this widget should have the option to be set to use
         // QInputDialog::getMultiLineText() for certain uses
         QString newString = QInputDialog::getText(this,
-                                                  tr("Enter text"),
+                                                  tr("Enter text") + " - AkariXB",
                                                   tr("Update the text for "
                                                      "this item") // kinda TMP
                                                   + "\n"
@@ -272,6 +323,7 @@ void StringListWidget::removeFromList()
 {
     const int row = m_listWidget->currentRow();
 
+    // FIXME: ask for confirmation? Could be optional upon widget creation
     if (row != -1)
     {
         QListWidgetItem *item = m_listWidget->takeItem(row);
