@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <QInputDialog>
 #include <QTextEdit>
 #include <QPushButton>
+#include <QMessageBox>
 
 #include <QDebug>
 
@@ -41,7 +42,8 @@ public:
     explicit StringListWidget(bool forKeyValues, QWidget *parent = nullptr);
     ~StringListWidget();
 
-    void setLowercaseItems(bool lowercase);
+    void setLowercaseItems(bool lowercaseItems);
+    void setDuplicatesAllowed(bool duplicatesAllowed);
 
     void clearList();
     void addStringsToList(QStringList stringList);
@@ -50,8 +52,11 @@ public:
     void addItemsToList(QVariantMap stringMap);
     QVariantMap getItemsFromList();
 
+    bool stringExists(QString text);
+
     void enableRelevantButtons();
 
+
 signals:
 
 
@@ -79,6 +84,7 @@ private:
 
     bool m_forKeyValues;
     bool m_lowercaseItems;
+    bool m_duplicatesAllowed;
 };
 
 #endif // STRINGLISTWIDGET_H
