@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include <QObject>
 #include <QString>
 #include <QStringList>
-#include <QRegExp>
+#include <QRegularExpression>
 
 #include <QDebug>
 
@@ -34,7 +34,7 @@ class VariableParser : public QObject
     Q_OBJECT
 
 public:
-    explicit VariableParser(QObject *parent = 0);
+    explicit VariableParser(QObject *parent = nullptr);
     ~VariableParser();
 
     void setOwnNickname(QString newNickname);
