@@ -30,6 +30,10 @@
             <numerusform>%Ln minutos</numerusform>
         </translation>
     </message>
+    <message>
+        <source>Not sending message to room %1 because I am not currently in it.</source>
+        <translation>No puedo enviar el mensaje a la sala %1 porque no estoy actualmente en ella.</translation>
+    </message>
 </context>
 <context>
     <name>ActivityModule</name>
@@ -186,8 +190,7 @@
     </message>
     <message>
         <source>Additional specific JIDs:</source>
-        <translatorcomment>FIXME: Habría que decidir si JID es masculino (IDentificador Jabber) o femenino (IDentificación Jabber)</translatorcomment>
-        <translation type="unfinished">JIDs específicos adicionales:</translation>
+        <translation>JIDs específicos adicionales:</translation>
     </message>
 </context>
 <context>
@@ -205,6 +208,10 @@
         <source>A new chat was started by %1.</source>
         <translation>%1 ha iniciado una nueva conversación.</translation>
     </message>
+    <message>
+        <source>There are no active chats</source>
+        <translation>No hay conversaciones activas</translation>
+    </message>
 </context>
 <context>
     <name>ChatWidget</name>
@@ -218,13 +225,17 @@
     </message>
     <message>
         <source>Joined room %1, as %2.</source>
-        <translatorcomment>Jan: no me convence esta string, creo que cambiaré la original para la v0.7</translatorcomment>
-        <translation type="unfinished">Se ha entrado a la sala %1, como %2.</translation>
+        <translatorcomment>Jan: no me convence esta string, creo que cambiaré la original para la v0.8 - FIXME</translatorcomment>
+        <translation>Se ha entrado a la sala %1, como %2.</translation>
     </message>
     <message>
         <source>Left room %1.</source>
         <translation>Se ha salido de la sala %1.</translation>
     </message>
+    <message>
+        <source>Room name is: %1</source>
+        <translation>El nombre de la sala es: %1</translation>
+    </message>
 </context>
 <context>
     <name>CommandHandler</name>
@@ -483,11 +494,11 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>Set an optional reply pattern</source>
-        <translation type="unfinished">Establece un patrón de respuesta opcional</translation>
+        <translation>Establece, opcionalmente, un patrón de respuesta</translation>
     </message>
     <message>
         <source>With a reply pattern you can make any possible reply to a command fit into a predefined structure, like having a specific symbol at the start or the end of the reply, or always start the reply with a fixed word.</source>
-        <translation type="unfinished">Con un patrón de respuesta, puedes hacer que cualquier respuesta posible encaje en una estructura predefinida, como tener un símbolo específico al principio o al final de la respuesta, o empezar siempre la respuesta con una palabra fija.</translation>
+        <translation>Con un patrón de respuesta, puedes hacer que cualquier respuesta posible encaje en una estructura predefinida, como tener un símbolo específico al principio o al final de la respuesta, o empezar siempre la respuesta con una palabra fija.</translation>
     </message>
     <message>
         <source>You can insert variables like %user%, %params%, %output%, %line% and %smiley%.</source>
@@ -497,18 +508,21 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     <message>
         <source>Usually, you will want to have the %output% variable somewhere in the pattern.</source>
         <comment>Do not translate %output%</comment>
-        <translation type="unfinished">Normalmente, te interesará tener la variable %output% en algún lugar del patrón.</translation>
+        <translation>Normalmente, te interesará tener la variable %output% en algún lugar del patrón.</translation>
     </message>
     <message>
         <source>If you don&apos;t set a reply pattern, replies in chatrooms will use the default pattern, %user%: %output%.</source>
         <comment>Do not translate %user% or %output%</comment>
-        <translatorcomment>Jan: Quizá podríamos ampliar la versión traducida con una aclaración en castellano entre paréntesis, tipo: (Usuario: Respuesta).</translatorcomment>
-        <translation type="unfinished">Si no estableces un patrón de respuesta, las respuestas en salas de charla usarán el patrón predefinido, %user%: %output%.</translation>
+        <translation>Si no estableces un patrón de respuesta, las respuestas en salas de charla usarán el patrón predefinido, %user%: %output% (Usuario: Respuesta).</translation>
     </message>
     <message>
         <source>Example: [RESULT] &gt; %output%</source>
         <comment>Do not translate %output%</comment>
-        <translation type="unfinished">Ejemplo: [RESULTADO] &gt; %output%</translation>
+        <translation>Ejemplo: [RESULTADO] &gt; %output%</translation>
+    </message>
+    <message>
+        <source>Explanation shown to users with the %1 command</source>
+        <translation>Explicación mostrada a los usuarios con el comando %1</translation>
     </message>
 </context>
 <context>
@@ -570,6 +584,10 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Connection ping interval</source>
         <translation>Intervalo de ping de la conexión</translation>
     </message>
+    <message>
+        <source>Program configuration saved.</source>
+        <translation>Se ha guardado la configuración del programa.</translation>
+    </message>
 </context>
 <context>
     <name>ConnectionDialog</name>
@@ -610,6 +628,96 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <translation>&amp;Conectar</translation>
     </message>
 </context>
+<context>
+    <name>ContactsModule</name>
+    <message>
+        <source>&amp;Start chat</source>
+        <translation>&amp;Iniciar conversación</translation>
+    </message>
+    <message>
+        <source>&amp;Add Contact</source>
+        <translation>&amp;Añadir contacto</translation>
+    </message>
+    <message>
+        <source>Rename Contact</source>
+        <translation>Renombrar contacto</translation>
+    </message>
+    <message>
+        <source>&amp;Remove Contact</source>
+        <translation>&amp;Eliminar contacto</translation>
+    </message>
+    <message>
+        <source>Enter the new name for %1</source>
+        <comment>%1 is contact&apos;s name + address</comment>
+        <translation>Introduce el nuevo nombre para %1</translation>
+    </message>
+    <message>
+        <source>Remove contact?</source>
+        <translation>¿Eliminar contacto?</translation>
+    </message>
+    <message>
+        <source>Do you want to remove %1 from your contact list?</source>
+        <comment>%1 is contact&apos;s name + address</comment>
+        <translation>¿Quieres eliminar a %1 de tu lista de contactos?</translation>
+    </message>
+    <message>
+        <source>Yes, remove</source>
+        <comment>Regarding a contact</comment>
+        <translation>Si, eliminarlo</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation>No</translation>
+    </message>
+    <message>
+        <source>Added %1 to the contact list.</source>
+        <comment>%1 is an XMPP address</comment>
+        <translation>Se ha añadido a %1 a la lista de contactos.</translation>
+    </message>
+    <message>
+        <source>Removed %1 from the contact list.</source>
+        <comment>%1 is an XMPP address</comment>
+        <translation>Se ha eliminado a %1 de la lista de contactos.</translation>
+    </message>
+    <message>
+        <source>Add a contact</source>
+        <translation>Añadir un contacto</translation>
+    </message>
+    <message>
+        <source>Accept Request</source>
+        <translation>Aceptar solicitud</translation>
+    </message>
+    <message>
+        <source>Refuse Request</source>
+        <translation>Rechazar solicitud</translation>
+    </message>
+    <message>
+        <source>Pending Subscription Requests</source>
+        <translation>Solicitudes de suscripción pendientes</translation>
+    </message>
+    <message>
+        <source>Accepted subscription request from %1.</source>
+        <comment>%1 is an XMPP address</comment>
+        <translation>Se ha aceptado la solicitud de suscripción de %1.</translation>
+    </message>
+    <message>
+        <source>Refused subscription request from %1.</source>
+        <comment>%1 is an XMPP address</comment>
+        <translation>Se ha rechazado la solicitud de suscripción de %1.</translation>
+    </message>
+    <message>
+        <source>Subscription status: %1</source>
+        <translation>Estado de la suscripción: %1</translation>
+    </message>
+    <message>
+        <source>Rename a contact</source>
+        <translation>Renombrar un contacto</translation>
+    </message>
+    <message>
+        <source>Enter the full XMPP address, with user@server format</source>
+        <translation>Introduce la dirección XMPP completa, con formato usuario@servidor</translation>
+    </message>
+</context>
 <context>
     <name>GeneralModule</name>
     <message>
@@ -633,6 +741,133 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <translation>Mensaje de estado:</translation>
     </message>
 </context>
+<context>
+    <name>HelpWidget</name>
+    <message>
+        <source>General Help</source>
+        <translation>Ayuda general</translation>
+    </message>
+    <message>
+        <source>Getting started</source>
+        <translation>Empezando</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Configuración</translation>
+    </message>
+    <message>
+        <source>Commands</source>
+        <translation>Comandos</translation>
+    </message>
+    <message>
+        <source>Activities</source>
+        <translation>Actividades</translation>
+    </message>
+    <message>
+        <source>Substitution syntax</source>
+        <translation>Sintaxis de sustituciones</translation>
+    </message>
+    <message>
+        <source>Command line options</source>
+        <translation>Opciones de línea de comandos</translation>
+    </message>
+    <message>
+        <source>Contents</source>
+        <translation>Índice</translation>
+    </message>
+    <message>
+        <source>The first time you start AkariXB you will see the Connection Settings window, where you need to enter the XMPP address the bot will use, and its password.</source>
+        <translation>La primera vez que inicies AkariXB, verás la ventana Configuración de la conexión, donde deberás introducir la dirección XMPP que usará el bot, y su contraseña.</translation>
+    </message>
+    <message>
+        <source>Each type of command has an explanation of how it works, visible while you&apos;re adding the new command.</source>
+        <translation>Cada tipo de comando tiene una explicación de como funciona, visible mientras añades el nuevo comando.</translation>
+    </message>
+    <message>
+        <source>There are several special words that can be entered inside custom strings like replies to commands, conversation texts and status messages, which will be replaced by the appropriate variable text at the time the string is used. These are:</source>
+        <translation>Hay varias palabras especiales que se pueden introducir dentro de las cadenas de texto personalizadas, como respuestas a comandos, textos de conversación y mensajes de estado, que serán reemplazadas por el texto variable apropiado en el momento en el que se use la cadena de texto. Estas son:</translation>
+    </message>
+    <message>
+        <source>Replaced by the name of the user to whom this message is directed. Nickname in the case of chatrooms, and account name in the case of chats with contacts.</source>
+        <translation>Reemplazada por el nombre del usuario a quien va dirigido este mensaje. El apodo en el caso de salas de charla, y el nombre de la cuenta en el caso de conversaciones con contactos.</translation>
+    </message>
+    <message>
+        <source>Used in a custom reply pattern for a command, this will be replaced by the original reply to that command.</source>
+        <translation>Usada en un patrón de respuesta personalizado para un comando, será reemplazada por la respuesta original al comando.</translation>
+    </message>
+    <message>
+        <source>This is replaced by a newline character.</source>
+        <translation>Esta se reemplazará por un carácter de salto de línea.</translation>
+    </message>
+    <message>
+        <source>This is replaced by a random old-style smiley face.</source>
+        <translation>Esta es reemplazada por un emoticono clásico al azar.</translation>
+    </message>
+    <message>
+        <source>Example: &apos;Hello %user%&apos; could be converted to &apos;Hello Mary&apos; if a user called Mary does something that triggers that reply.</source>
+        <translation>Ejemplo: &apos;Hola %user%&apos; se podría convertir en &apos;Hola María&apos; si una usuaria llamada María hace algo que active esa respuesta.</translation>
+    </message>
+    <message>
+        <source>In addition, syntax like %1 can be used to insert one out of several choices at random, at any desired point in the string.</source>
+        <translation>Además, se puede usar sintaxis como %1 para insertar una de entre varias posibilidades al azar, en cualquier punto que se desee de la cadena de texto.</translation>
+    </message>
+    <message>
+        <source>You can use the --config parameter (or -c) to run the program with a different configuration. This way, you can run two instances of AkariXB at the same time, with different accounts, different rooms configured, using a different command prefix, etc.</source>
+        <translation>Puedes usar el parámetro --config (o -c) para ejecutar el programa con una configuración diferente. De esta manera, puedes ejecutar dos instancias de AkariXB al mismo tiempo, con diferentes cuentas, diferentes salas configuradas, usando un prefijo de comandos diferente, etc.</translation>
+    </message>
+    <message>
+        <source>Use the --debug parameter (or -d) to have extra information in your terminal window, about what the program is doing.</source>
+        <translation>Usa el parámetro --debug (o -d) para tener información adicional en la ventana de la terminal, sobre lo que está haciendo el programa.</translation>
+    </message>
+    <message>
+        <source>Use the --xmppdebug parameter (or -x) to have extensive XMPP traffic information (XML stanzas) shown in your terminal window.</source>
+        <translation>Usa el parámetro --xmppdebug (o -x) para tener información exhaustiva del tráfico XMPP (stanzas XML) mostrada en la ventana de la terminal.</translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation>&amp;Cerrar</translation>
+    </message>
+    <message>
+        <source>These are replaced by a random, happy or sad, Unicode-based emoji face.</source>
+        <translation>Estas son reemplazadas por una cara emoji (Unicode) feliz o triste, al azar.</translation>
+    </message>
+    <message>
+        <source>Keep in mind that some users might not be able to see these symbols.</source>
+        <translation>Recuerda que quizá algunos usuarios no puedan ver estos símbolos.</translation>
+    </message>
+    <message>
+        <source>%1, %2 and %3 can&apos;t be used inside these choices.</source>
+        <translation>%1, %2 y %3 no se pueden usar dentro de dichas posibilidades.</translation>
+    </message>
+    <message>
+        <source>Afterwards, you can configure chatrooms to be automatically joined, manage the contact list, define commands for which the bot will provide answers, etc.</source>
+        <translation>A continuación, puedes configurar salas de charla a las que entrar automáticamente, gestionar la lista de contactos, definir comandos para los que el bot dará respuestas, etc.</translation>
+    </message>
+    <message>
+        <source>Activities can be defined to make the bot change its status, send messages, adapt its reaction time and so on, at certain times and dates.</source>
+        <translation>Se pueden definir actividades para hacer que el bot cambie su estado, envíe mensajes, adapte su tiempo de reacción, etc, a ciertas horas y en ciertas fechas.</translation>
+    </message>
+    <message>
+        <source>If you have defined messages to be sent before or after the activity, you can decrease the chances of them being sent by adding some strings with a single asterisk (*) in them to the list of messages.</source>
+        <translation>Si has definido mensajes para enviar antes o después de la actividad, puedes reducir las posibilidades de que se envíen añadiendo algunas cadenas de texto con un único asterisco (*) en ellas, a la lista de mensajes.</translation>
+    </message>
+    <message>
+        <source>In replies to commands, this is replaced with whatever follows the command name.</source>
+        <translation>En respuestas a comandos, esta es reemplazada con cualquier cosa que siga al nombre del comando.</translation>
+    </message>
+    <message>
+        <source>You can define several kinds of custom commands, like static message, random message from a list, keyword-based message, and program execution-based commands.</source>
+        <translation>Puedes definir varios tipos de comandos personalizados, como mensaje estático, mensaje aleatorio de una lista, mensaje basado en palabras clave, y comandos basados en la ejecución de programas.</translation>
+    </message>
+    <message>
+        <source>You can configure several things to your liking in the settings, like which symbol will act as prefix for commands, which XMPP addresses will be able to use special administration commands with the bot, whether you want popup notifications for certain events, etc.</source>
+        <translation>Puedes ajustar varias cosas a tu gusto en la configuración, como qué símbolo servirá de prefijo para comandos, qué direcciones XMPP podrán usar comandos especiales de administración con el bot, si quieres notificaciones emergentes para ciertos eventos, etc.</translation>
+    </message>
+    <message>
+        <source>If the access level for the command is not set for everyone, only users listed in the administrators list in the Program Configuration window will be able to use that command.</source>
+        <translation>Si el nivel de acceso del comando no está establecido para todo el mundo, solo los usuarios presentes en la lista de administradores de la ventana Configuración del programa podrán usar ese comando.</translation>
+    </message>
+</context>
 <context>
     <name>IdentityModule</name>
     <message>
@@ -651,7 +886,11 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     <message>
         <source>Saved identity data for %1.</source>
         <comment>%1 is a nickname</comment>
-        <translation>Datos de identidad guardados para %1.</translation>
+        <translation>Se han guardado los datos de identidad para %1.</translation>
+    </message>
+    <message>
+        <source>Identity data has not been defined yet.</source>
+        <translation>Los datos de identidad aún no se han definido.</translation>
     </message>
 </context>
 <context>
@@ -759,7 +998,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>Conversation</source>
-        <translatorcomment>FIXME</translatorcomment>
+        <translatorcomment>FIXME? la original quizá cambie a Speech o similar</translatorcomment>
         <translation type="unfinished">Conversación</translation>
     </message>
     <message>
@@ -776,7 +1015,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>Data directory created: %1</source>
-        <translation>Directorio de datos creado: %1</translation>
+        <translation>Se ha creado el directorio de datos: %1</translation>
     </message>
     <message>
         <source>Error creating data directory: %1</source>
@@ -850,6 +1089,51 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Connection seems stuck. Trying again...</source>
         <translation>La conexión parece haberse atascado. Intentándolo de nuevo...</translation>
     </message>
+    <message>
+        <source>Contacts</source>
+        <translation>Contactos</translation>
+    </message>
+    <message>
+        <source>Stop connection attempts</source>
+        <translation>Detener los intentos de conexión</translation>
+    </message>
+    <message>
+        <source>General &amp;Help</source>
+        <translation>&amp;Ayuda general</translation>
+    </message>
+    <message>
+        <source>Aborted connection attempt.</source>
+        <translation>Se ha interrumpido el intento de conexión.</translation>
+    </message>
+    <message>
+        <source>Presence error %1 from %2: %3</source>
+        <translation>Error de presencia %1 de %2: %3</translation>
+    </message>
+    <message>
+        <source>%1 wants to subscribe to your presence.</source>
+        <comment>%1 is another user&apos;s address</comment>
+        <translation>%1 quiere suscribirse a tu presencia.</translation>
+    </message>
+    <message>
+        <source>%1 unsubscribed from your presence.</source>
+        <comment>%1 is another user&apos;s address</comment>
+        <translation>%1 ha cancelado su suscripción a tu presencia.</translation>
+    </message>
+    <message>
+        <source>%1 removed your authorization to see their presence.</source>
+        <comment>%1 is another user&apos;s address</comment>
+        <translatorcomment>Kheiron: ¿quitado o retirado?</translatorcomment>
+        <translation>%1 ha quitado tu autorización para ver su presencia.</translation>
+    </message>
+    <message>
+        <source>%1 accepted your subscription request.</source>
+        <comment>%1 is another user&apos;s address</comment>
+        <translation>%1 ha aceptado tu solicitud de suscripción.</translation>
+    </message>
+    <message>
+        <source>Settings file in use: %1</source>
+        <translation>Archivo de configuración en uso: %1</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -858,9 +1142,10 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <translation>Error %1 de %2: %3</translation>
     </message>
     <message>
-        <source>Headline from %1</source>
-        <translatorcomment>FIXME? Psi usa &quot;titular&quot;; comprobar con Swift/Gajim/otros...</translatorcomment>
-        <translation type="unfinished">Titular de %1</translation>
+        <source>Headline from %1: %2</source>
+        <comment>%1 is a user&apos;s address,%2 is the title of a message</comment>
+        <translatorcomment>Psi usa &quot;titular&quot;; Gajim no parece tener una string para &quot;Headline&quot;</translatorcomment>
+        <translation>Titular de %1: %2</translation>
     </message>
 </context>
 <context>
@@ -904,7 +1189,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>%1 as %2</source>
-        <translatorcomment>FIXME: meh...</translatorcomment>
+        <translatorcomment>FIXME: meh... Esto desaparecerá cuando la lista de salas pase a ser una tabla en condiciones.</translatorcomment>
         <translation type="unfinished">%1 como %2</translation>
     </message>
     <message>
@@ -937,7 +1222,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>Joining room %1...</source>
-        <translation>Entrant a la sala %1...</translation>
+        <translation>Entrando a la sala %1...</translation>
     </message>
     <message>
         <source>Password, if needed</source>
@@ -954,6 +1239,30 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
             <numerusform>Se han cargado %Ln salas.</numerusform>
         </translation>
     </message>
+    <message numerus="yes">
+        <source>Saved %Ln room(s).</source>
+        <translation>
+            <numerusform>Se ha guardado una sala.</numerusform>
+            <numerusform>Se han guardado %Ln salas.</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Remove room?</source>
+        <translation>¿Quitar sala?</translation>
+    </message>
+    <message>
+        <source>Yes, remove it</source>
+        <comment>It = A chat room</comment>
+        <translation>Si, quitarla</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation>No</translation>
+    </message>
+    <message>
+        <source>Do you want to remove room %1 from your list?</source>
+        <translation>¿Quieres quitar la sala %1 de la lista?</translation>
+    </message>
 </context>
 <context>
     <name>StringListWidget</name>
@@ -969,5 +1278,29 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Update the text for this item</source>
         <translation>Actualiza el texto de este elemento</translation>
     </message>
+    <message>
+        <source>Add an item to the list</source>
+        <translation>Añadir un elemento a la lista</translation>
+    </message>
+    <message>
+        <source>Edit the selected item (you can also double-click it)</source>
+        <translation>Editar el elemento seleccionado (también puedes hacer doble clic en él)</translation>
+    </message>
+    <message>
+        <source>Remove the selected item</source>
+        <translation>Quitar el elemento seleccionado</translation>
+    </message>
+    <message>
+        <source>Update the definition of the item</source>
+        <translation>Actualizar la definición de este elemento</translation>
+    </message>
+    <message>
+        <source>The item already exists</source>
+        <translation>El elemento ya existe</translation>
+    </message>
+    <message>
+        <source>Error: There is already an item in the list with the text %1, and this list does not allow duplicates.</source>
+        <translation>Error: Ya hay un elemento en la lista con el texto %1, y esta lista no permite duplicados.</translation>
+    </message>
 </context>
 </TS>
